@@ -151,6 +151,9 @@ class OpenADRClient:
             self.scheduler.shutdown()
         if self.report_queue_task:
             self.report_queue_task.cancel()
+        delayed_call_tasks = [task for task in asyncio.all_tasks() if task.get_name().startswith('DelayedCall')]
+        for task in delayed_call_tasks:
+            task.cancel()
         await self.client_session.close()
         await asyncio.sleep(0)
 
@@ -601,7 +604,8 @@ class OpenADRClient:
                 if self.allow_jitter:
                     delay = random.uniform(0, min(30, report_interval / 2))
                     self.loop.create_task(utils.delayed_call(func=self.pending_reports.put(outgoing_report),
-                                                             delay=delay))
+                                                             delay=delay),
+                                          name=f'DelayedCall-{utils.generate_id()}')
                 else:
                     await self.pending_reports.put(self.incomplete_reports.pop(report_request_id))
             else:
@@ -612,7 +616,8 @@ class OpenADRClient:
             if self.allow_jitter:
                 delay = random.uniform(0, min(30, granularity.total_seconds() / 2))
                 self.loop.create_task(utils.delayed_call(func=self.pending_reports.put(outgoing_report),
-                                                         delay=delay))
+                                                         delay=delay),
+                                      name=f'DelayedCall-{utils.generate_id()}')
             else:
                 await self.pending_reports.put(outgoing_report)
 
@@ -664,6 +669,11 @@ class OpenADRClient:
         if event['event_descriptor']['event_id'] in self.events:
             return self.responded_events['event_id']
 
+    async def on_register_report(self, report):
+        """
+        Placeholder for the on_register_report handler.
+        """
+
     ###########################################################################
     #                                                                         #
     #                                  LOW LEVEL                              #
@@ -793,6 +803,11 @@ class OpenADRClient:
                 for report_request in response_payload['report_requests']:
                     await self.create_report(report_request)
 
+        elif response_type == 'oadrRegisterReport':
+            if 'reports' in response_payload and len(response_payload['reports']) > 0:
+                for report in response_payload['reports']:
+                    await self.register_report(report)
+
         else:
             logger.warning(f"No handler implemented for incoming message "
                            f"of type {response_type}, ignoring.")
