@@ -92,7 +92,7 @@ class Target:
 
 @dataclass
 class EventDescriptor:
-    event_id: int
+    event_id: str
     modification_number: int
     market_context: str
     event_status: str
@@ -117,9 +117,9 @@ class ActivePeriod:
     dtstart: datetime
     duration: timedelta
     tolerance: dict = None
-    notification: dict = None
-    ramp_up: dict = None
-    recovery: dict = None
+    notification_period: dict = None
+    ramp_up_period: dict = None
+    recovery_period: dict = None
 
 
 @dataclass
