@@ -23,6 +23,7 @@ from openleadr import utils
 from functools import partial
 from datetime import datetime, timedelta, timezone
 from collections import deque
+import asyncio
 import logging
 import ssl
 import re
@@ -142,6 +143,9 @@ class OpenADRServer:
         await self.run()
 
     async def stop(self):
+        delayed_call_tasks = [task for task in asyncio.all_tasks() if task.get_name().startswith('DelayedCall')]
+        for task in delayed_call_tasks:
+            task.cancel()
         await self.app_runner.cleanup()
 
     def add_event(self, ven_id, signal_name, signal_type, intervals, callback, targets=None,
@@ -220,16 +224,21 @@ class OpenADRServer:
         self.services['event_service'].pending_events[event_id] = (event, callback)
         return event_id
 
-    def add_raw_event(self, ven_id, event):
+    def add_raw_event(self, ven_id, event, callback):
         """
         Add a new event to the queue for a specific VEN.
         :param str ven_id: The ven_id to which this event should be distributed.
         :param dict event: The event (as a dict or as a objects.Event instance)
                            that contains the event details.
+        :param callable callback: A callback that will receive the opt status for this event.
+                                  This callback receives ven_id, event_id, opt_type as its arguments.
         """
         if ven_id not in self.message_queues:
             self.message_queues[ven_id] = deque()
+        event_id = utils.getmember(utils.getmember(event, 'event_descriptor'), 'event_id')
         self.message_queues[ven_id].append(event)
+        self.services['event_service'].pending_events[event_id] = (event, callback)
+        return event_id
 
     def add_handler(self, name, func):
         """
